/***************************************************************************
                          qtcups.h  -  description
                             -------------------
    begin                : Tue Jan 23 2001
    copyright            : (C) 2001 by Michael Goffioul
    email                : goffioul@imec.be
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QTCUPS_H
#define QTCUPS_H

#include <qstring.h>

class QTranslator;

class QtCUPS
{
public:
	static void setLocale(const QString& lang = QString::null);

private:
	static QTranslator	*t;
};

#endif
