/****************************************************************************
** Form interface generated from reading ui file './qcupsprintdialogbase.ui'
**
** Created: Wed May 22 09:13:58 2002
**      by:  The User Interface Compiler (uic)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/
#ifndef QCUPSPRINTDIALOGBASE_H
#define QCUPSPRINTDIALOGBASE_H

#include <qvariant.h>
#include <qdialog.h>
class QVBoxLayout; 
class QHBoxLayout; 
class QGridLayout; 
class QButtonGroup;
class QCheckBox;
class QComboBox;
class QGroupBox;
class QLabel;
class QLineEdit;
class QPushButton;
class QRadioButton;
class QSpinBox;

class QCupsPrintDialogBase : public QDialog
{ 
    Q_OBJECT

public:
    QCupsPrintDialogBase( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~QCupsPrintDialogBase();

    QGroupBox* printerbox_;
    QLabel* type_;
    QLabel* namelabel_;
    QLabel* location_;
    QLabel* TextLabel3;
    QLabel* TextLabel6;
    QLabel* TextLabel5;
    QLabel* comment_;
    QLabel* state_;
    QLabel* TextLabel4;
    QComboBox* dest_;
    QPushButton* propbutton_;
    QPushButton* setdefault_;
    QButtonGroup* pagebox_;
    QRadioButton* all_;
    QRadioButton* current_;
    QRadioButton* range_;
    QLineEdit* rangeedit_;
    QLabel* TextLabel11;
    QLabel* TextLabel1;
    QComboBox* pagecombo_;
    QPushButton* optionsbutton_;
    QGroupBox* copiesbox_;
    QLabel* copieslabel_;
    QSpinBox* copies_;
    QLabel* copiespix_;
    QCheckBox* collate_;
    QCheckBox* reverse_;
    QPushButton* okbutton_;
    QPushButton* cancelbutton_;


protected slots:
    virtual void collateClicked();
    virtual void optionsClicked();
    virtual void printerSelected(int);
    virtual void propertyClicked();
    virtual void rangeEntered();
    virtual void setDefaultClicked();

protected:
    QVBoxLayout* QCupsPrintDialogBaseLayout;
    QHBoxLayout* printerbox_Layout;
    QGridLayout* Layout20;
    QVBoxLayout* Layout17;
    QGridLayout* Layout13;
    QVBoxLayout* pagebox_Layout;
    QVBoxLayout* Layout10;
    QHBoxLayout* Layout8;
    QHBoxLayout* Layout1;
    QHBoxLayout* Layout11;
    QVBoxLayout* copiesbox_Layout;
    QHBoxLayout* Layout5;
    QHBoxLayout* Layout4;
    QVBoxLayout* Layout2;
    QHBoxLayout* Layout6;
};

#endif // QCUPSPRINTDIALOGBASE_H
